TrustedSecret #
A Trusted Secret is an external data, encrypted by CloudForet.
Package : spaceone.api.secret.v1
TrustedSecret #
TrustedSecret Methods:
create #
Creates a new Trusted Secret. When creating the resource, external data is encrypted, and a trusted_secret_id is issued for data access by other microservices.
POST /secret/v1/trusted-secret/create
name (string)
Requireddata (Struct)
Requireddomain_id (string)
Requiredtags (Struct)
schema (string)
service_account_id (string)
{
"name": "aws-dev",
"data": "********",
"schema": "aws_access_key",
"service_account_id": "sa-123456789012",
"tags": {},
"domain_id": "domain-123456789012"
}trusted_secret_id (string)
Requiredname (string)
Requiredtags (Struct)
Requiredschema (string)
Requiredprovider (string)
Requiredservice_account_id (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Required
{
"trusted_secret_id": "trusted-secret-123456789012",
"name": "aws-dev",
"tags": {},
"schema": "aws_access_key",
"provider": "aws",
"service_account_id": "sa-123456789012",
"domain_id": "domain-123456789012",
"created_at": "2022-01-01T06:10:14.851Z"
}update #
Updates a specific Secret. You can make changes in Secret settings, including name andtags.
POST /secret/v1/trusted-secret/update
trusted_secret_id (string)
Requireddomain_id (string)
Requiredname (string)
tags (Struct)
{
"trusted_secret_id": "trusted-secret-123456789012",
"name": "aws-dev2",
"tags": { "a": "b"},
"domain_id": "domain-123456789012"
}trusted_secret_id (string)
Requiredname (string)
Requiredtags (Struct)
Requiredschema (string)
Requiredprovider (string)
Requiredservice_account_id (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Required
{
"trusted_secret_id": "trusted-secret-123456789012",
"name": "aws-dev",
"tags": {},
"schema": "aws_access_key",
"provider": "aws",
"service_account_id": "sa-123456789012",
"domain_id": "domain-123456789012",
"created_at": "2022-01-01T06:10:14.851Z"
}delete #
Deletes a specific Secret. You must specify the secret_id of the Secret to delete.
POST /secret/v1/trusted-secret/delete
trusted_secret_id (string)
Requireddomain_id (string)
Required
{
"trusted_secret_id": "trusted-secret-123456789012",
"domain_id": "domain-123456789012"
}update_data #
Updates encrypted data of a specific Secret resource. For example, to change the parameter data, external data to encrypt, you can use update_data to create new encrypted data based on the changed data and store it in the Secret resource.
POST /secret/v1/trusted-secret/update-data
UpdateTrustedSecretDataRequest
trusted_secret_id (string)
Requireddata (Struct)
Requireddomain_id (string)
Requiredschema (string)
{
"trusted_secret_id": "trusted-secret-123456789012",
"data": "********",
"domain_id": "domain-123456789012"
}get #
Gets a specific Post. You must specify the post_id of the Post to get, and the board_id of the Board where the child Post to get belongs. Prints detailed information about the Post.
POST /secret/v1/trusted-secret/get
trusted_secret_id (string)
Requireddomain_id (string)
Requiredonly (string)
Repeated
{
"trusted_secret_id": "trusted-secret-123456789012",
"domain_id": "domain-123456789012"
}trusted_secret_id (string)
Requiredname (string)
Requiredtags (Struct)
Requiredschema (string)
Requiredprovider (string)
Requiredservice_account_id (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Required
{
"trusted_secret_id": "trusted-secret-123456789012",
"name": "aws-dev",
"tags": {},
"schema": "aws_access_key",
"provider": "aws",
"service_account_id": "sa-123456789012",
"domain_id": "domain-123456789012",
"created_at": "2022-01-01T06:10:14.851Z"
}list #
Gets a list of all Posts. You can use a query to get a filtered list of Posts.
POST /secret/v1/trusted-secret/list
domain_id (string)
Requiredquery (Query)
trusted_secret_id (string)
name (string)
schema (string)
provider (string)
service_account_id (string)
{
"query": {},
"domain_id": "domain-123456789012"
}results (TrustedSecretInfo)
RepeatedRequiredtotal_count (int32)
Required
{
"results": [
{
"trusted_secret_id": "trusted-secret-123456789012",
"name": "aws-dev",
"tags": {},
"schema": "aws_access_key",
"provider": "aws",
"service_account_id": "sa-123456789012",
"domain_id": "domain-123456789012",
"created_at": "2022-01-01T06:10:14.851Z"
},
{
"trusted_secret_id": "trusted-secret-987654321098",
"name": "plugin-credentials",
"tags": {},
"domain_id": "domain-123456789012",
"created_at": "2022-01-01T02:31:01.709Z"
}
],
"total_count": 2
}stat #
POST /secret/v1/trusted-secret/stat
Message #
CreateTrustedSecretRequest #
name (string)
Requireddata (Struct)
Requireddomain_id (string)
Requiredtags (Struct)
schema (string)
service_account_id (string)
GetTrustedSecretRequest #
trusted_secret_id (string)
Requireddomain_id (string)
Requiredonly (string)
Repeated
TrustedSecretInfo #
trusted_secret_id (string)
Requiredname (string)
Requiredtags (Struct)
Requiredschema (string)
Requiredprovider (string)
Requiredservice_account_id (string)
Requiredproject_id (string)
Requireddomain_id (string)
Requiredcreated_at (string)
Required
TrustedSecretQuery #
domain_id (string)
Requiredquery (Query)
trusted_secret_id (string)
name (string)
schema (string)
provider (string)
service_account_id (string)
TrustedSecretRequest #
trusted_secret_id (string)
Requireddomain_id (string)
Required
TrustedSecretStatQuery #
query (StatisticsQuery)
Requireddomain_id (string)
Required
TrustedSecretsInfo #
results (TrustedSecretInfo)
RepeatedRequiredtotal_count (int32)
Required
UpdateTrustedSecretDataRequest #
trusted_secret_id (string)
Requireddata (Struct)
Requireddomain_id (string)
Requiredschema (string)
UpdateTrustedSecretRequest #
trusted_secret_id (string)
Requireddomain_id (string)
Requiredname (string)
tags (Struct)